@@ -53,6 +53,10 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.SortedSet;
 import java.util.TreeSet;
+
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.Component;
 
@@ -61,6 +65,7 @@ import com.openexchange.groupware.Component;
  */
 public abstract class Exceptions<T extends AbstractOXException> {
 
+	private static final Log LOG = LogFactory.getLog(Exceptions.class);
     
     private final Map<Integer, ErrorMessage> errors = new HashMap<Integer, ErrorMessage>();
 
@@ -130,7 +135,7 @@ public abstract class Exceptions<T extends AbstractOXException> {
             if(initialized) {
                 throw new UndeclaredErrorCodeException(code, getApplicationId(), getComponent());
             } else {
-                System.err.println("Apparently this exception factory was not registered.: "+this);
+            	LOG.error("Apparently this exception factory was not registered: " + this);
                 setComponent(new StringComponent("???"));
                 setApplicationId("unset");
                 return create(code, cause, args);
