@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -74,6 +74,8 @@ import org.apache.commons.logging.LogFactory;
  */
 public abstract class ServiceHolder<S> {
 
+    private static final Object PRESENT = new Object();
+
     private final class ServiceHolderTask extends TimerTask {
 
         @Override
@@ -187,8 +189,6 @@ public abstract class ServiceHolder<S> {
 
     private static Timer serviceHolderTimer;
 
-    private static final Object DUMMY = new Object();
-
     private static final Log LOG = LogFactory.getLog(ServiceHolder.class);
 
     private static final String printStackTrace(final StackTraceElement[] trace) {
@@ -203,7 +203,7 @@ public abstract class ServiceHolder<S> {
 
     private final Map<String, ServiceHolderListener<S>> listeners;
 
-    private final Map<Thread, Map<ServiceProxy, Object>> usingThreads = new ConcurrentHashMap<Thread, Map<ServiceProxy, Object>>();
+    private final Map<Thread, Map<ServiceProxy, Object>> usingThreads;
 
     private final AtomicBoolean waiting;
 
@@ -214,6 +214,7 @@ public abstract class ServiceHolder<S> {
      */
     protected ServiceHolder() {
         super();
+        usingThreads = new ConcurrentHashMap<Thread, Map<ServiceProxy, Object>>();
         countActive = new AtomicInteger();
         waiting = new AtomicBoolean();
         listeners = new ConcurrentHashMap<String, ServiceHolderListener<S>>();
@@ -271,11 +272,14 @@ public abstract class ServiceHolder<S> {
             final Thread thread = Thread.currentThread();
             Map<ServiceProxy, Object> proxySet = usingThreads.get(thread);
             if (null == proxySet) {
-                proxySet = new ConcurrentHashMap<ServiceProxy, Object>(4);
-                usingThreads.put(thread, proxySet);
+                final Map<ServiceProxy, Object> newProxySet = new ConcurrentHashMap<ServiceProxy, Object>();
+                proxySet = usingThreads.put(thread, newProxySet);
+                if (null == proxySet) {
+                    proxySet = newProxySet;
+                }
             }
             final ServiceProxy proxy = new ServiceProxy(serviceReference.get(), thread.getStackTrace());
-            proxySet.put(proxy, DUMMY);
+            proxySet.put(proxy, PRESENT);
             return proxy.newProxyInstance();
         }
         return serviceReference.get();
