@@ -49,6 +49,7 @@
 
 package com.openexchange.sessiond;
 
+import java.util.Collection;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.session.Session;
 import com.openexchange.sessiond.exception.SessiondException;
@@ -114,7 +115,18 @@ public interface SessiondService {
     public int getUserSessions(final int userId, final int contextId);
 
     /**
-     * Get the session object related to the given session ID.
+     * Gets the <b>local-only</b> sessions associated with specified user in given context.
+     * <p>
+     * <b>Note</b>: Remote sessions are not considered by this method.
+     * 
+     * @param userId The user identifier
+     * @param contextId The context identifier
+     * @return The <b>local-only</b> sessions associated with specified user in given context
+     */
+    public Collection<Session> getSessions(int userId, int contextId);
+
+    /**
+     * Get the session object related to the given session identifier.
      * 
      * @param sessionId - The Session ID
      * @return Return the session object or null if no session exists for the given ID or if the session is expired
@@ -130,17 +142,6 @@ public interface SessiondService {
      */
     public Session getSessionByRandomToken(final String randomToken, final String localIp);
 
-    /**
-     * Gets (and removes) the session bound to given secret cookie identifier in cache.
-     * <p>
-     * Session is going to be added to local session containers on a cache hit.
-     * 
-     * @param sessionId The session identifier (which is sent as <i>"session=..."</i> in every request)
-     * @param localIP The host's local IP address
-     * @return The cached session or <code>null</code> on cache miss.
-     */
-    public Session getCachedSession(final String sessionId, final String localIP);
-
     /**
      * The number of active sessions.
      * 
